diff --git a/doc/html/configurator.easy.html.in b/doc/html/configurator.easy.html.in
index 9b4ad407913ca4b27395328ac60635556e9291c2..4709f947ac7bc651002210f69097aeea2d003259 100644
--- a/doc/html/configurator.easy.html.in
+++ b/doc/html/configurator.easy.html.in
@@ -508,7 +508,7 @@ from multiple Slurm-managed clusters.<br>
 
 <H2>Process ID Logging</H2>
 Define the location into which we can record the daemon's process ID.
-This is used for locate the appropriate daemon for signalling.
+This is used for locate the appropriate daemon for signaling.
 Specify a specify the fully qualified pathname for the file.
 <P>
 <input type="text" name="slurmctld_pid_file" value="/var/run/slurmctld.pid">
diff --git a/doc/html/configurator.html.in b/doc/html/configurator.html.in
index f6de8f690e05bf98bbaa9159a502a3b722c4d089..c50464ed775968aff5a08a25e702f406dcfc2017 100644
--- a/doc/html/configurator.html.in
+++ b/doc/html/configurator.html.in
@@ -752,7 +752,7 @@ from multiple Slurm-managed clusters.<br>
 
 <H2>Process ID Logging</H2>
 Define the location into which we can record the daemon's process ID.
-This is used for locate the appropriate daemon for signalling.
+This is used for locate the appropriate daemon for signaling.
 Specify a specify the fully qualified pathname for the file.
 <P>
 <input type="text" name="slurmctld_pid_file" value="/var/run/slurmctld.pid">
diff --git a/doc/html/programmer_guide.shtml b/doc/html/programmer_guide.shtml
index 05370122670dd9197c39bd1a16fe9226dea65f54..2b7aa9a9e28b08601121653c1801870028abe3f2 100644
--- a/doc/html/programmer_guide.shtml
+++ b/doc/html/programmer_guide.shtml
@@ -177,7 +177,7 @@ See <b>doc/man/man5/slurm.conf.5</b> and the man pages for other configuration f
 for more details.
 <b>init.d.slurm</b> is a script that determines which
 Slurm daemon(s) should execute on any node based upon the configuration file contents.
-It will also manage these daemons: starting, signalling, restarting, and stopping them.</p>
+It will also manage these daemons: starting, signaling, restarting, and stopping them.</p>
 
 <h2>Test Suite</h2>
 <p>The <b>testsuite</b> files use a DejaGnu framework for testing. These tests
diff --git a/doc/man/man1/sbatch.1 b/doc/man/man1/sbatch.1
index b19ac0a3b71609129aaefa50f7258ee06a47c052..26fec47e90e98bb6e1666ce4bac49cfa76c29840 100644
--- a/doc/man/man1/sbatch.1
+++ b/doc/man/man1/sbatch.1
@@ -1412,7 +1412,7 @@ By default, no signal is sent before the job's end time.
 If a \fIsig_num\fR is specified without any \fIsig_time\fR,
 the default time will be 60 seconds.
 Use the "B:" option to signal only the batch shell, none of the other
-processes will be signaled. By default all job steps will be signalled,
+processes will be signaled. By default all job steps will be signaled,
 but not the batch shell itself.
 
 .TP
diff --git a/doc/man/man1/scancel.1 b/doc/man/man1/scancel.1
index 6bb80179c4342629a3b7d0c2e9951652965833f1..58de17e77a1aed7d10f0828d9aa8df9d3b19f418 100644
--- a/doc/man/man1/scancel.1
+++ b/doc/man/man1/scancel.1
@@ -154,12 +154,12 @@ If neither \fB\-\-batch\fR nor \fB\-\-signal\fR are used,
 the entire job will be terminated.
 
 When \fB\-\-batch\fR is used, the batch shell processes will be signaled.
-The child processes of the shell will not be signalled by Slurm, but
+The child processes of the shell will not be signaled by Slurm, but
 the shell may forward the signal.
 
 When \fB\-\-batch\fR is not used but \fB\-\-signal\fR is used,
-then all job steps will be signalled, but the batch script itself
-will not be signalled.
+then all job steps will be signaled, but the batch script itself
+will not be signaled.
 
 .SH "ENVIRONMENT VARIABLES"
 .PP
diff --git a/slurm/slurm.h.in b/slurm/slurm.h.in
index ea1975f0e39015937ed508027a17afa11c26319a..ce2838d141f0203fcec609d4e5b4dcf8dd62eeb9 100644
--- a/slurm/slurm.h.in
+++ b/slurm/slurm.h.in
@@ -2880,7 +2880,7 @@ typedef struct slurm_ctl_conf {
 	char *unkillable_program; /* program run by the slurmstepd when
 				   * processes in a job step are unkillable */
 	uint16_t unkillable_timeout; /* time in seconds, after processes in a
-				      * job step have been signalled, before
+				      * job step have been signaled, before
 				      * they are considered "unkillable". */
 	uint16_t use_pam;	/* enable/disable PAM support */
 	uint16_t use_spec_resources; /* enable/disable job control over
diff --git a/src/common/eio.c b/src/common/eio.c
index e5d7ca5b102132fc11c0823450886fcdd520d8f8..8166fb4065fc1ee4d8a8425850e4996aa91b81be 100644
--- a/src/common/eio.c
+++ b/src/common/eio.c
@@ -311,7 +311,7 @@ int eio_handle_mainloop(eio_handle_t *eio)
 			goto done;
 
 		/*
-		 *  Setup eio handle signalling fd
+		 *  Setup eio handle signaling fd
 		 */
 		pollfds[nfds].fd     = eio->fds[0];
 		pollfds[nfds].events = POLLIN;
diff --git a/src/common/node_select.c b/src/common/node_select.c
index 74ba99c617184321124e43db69a1ae80acdb85b6..7ec513b5a7a006e388f7ef543f0942b8b021c0a7 100644
--- a/src/common/node_select.c
+++ b/src/common/node_select.c
@@ -609,9 +609,9 @@ extern int select_g_job_resized(struct job_record *job_ptr,
 }
 
 /*
- * Pass job-step signal to plugin before signalling any job steps, so that
+ * Pass job-step signal to plugin before signaling any job steps, so that
  * any signal-dependent actions can be taken.
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  * IN signal  - signal(7) number
  */
 extern int select_g_job_signal(struct job_record *job_ptr, int signal)
diff --git a/src/common/node_select.h b/src/common/node_select.h
index 0055d3d9a1a8ace16cb393c4fe6cd43dd72ccd6a..e8679a0b7fa5590deee6d9138a489085c3465152 100644
--- a/src/common/node_select.h
+++ b/src/common/node_select.h
@@ -596,9 +596,9 @@ extern int select_g_job_ready(struct job_record *job_ptr);
 extern int select_g_job_fini(struct job_record *job_ptr);
 
 /*
- * Pass job-step signal to plugin before signalling any job steps, so that
+ * Pass job-step signal to plugin before signaling any job steps, so that
  * any signal-dependent actions can be taken.
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  * IN signal  - signal(7) number
  */
 extern int select_g_job_signal(struct job_record *job_ptr, int signal);
diff --git a/src/common/slurm_acct_gather_profile.c b/src/common/slurm_acct_gather_profile.c
index 18d52813b283417cbd376884985ce3d6c19665de..ce40b0d130b9cd03e94990bd857fdfcd54a21418 100644
--- a/src/common/slurm_acct_gather_profile.c
+++ b/src/common/slurm_acct_gather_profile.c
@@ -171,7 +171,7 @@ static void *_timer_thread(void *args)
 				continue;
 			if (!acct_gather_profile_test())
 				break;	/* Shutting down */
-			debug2("profile signalling type %s",
+			debug2("profile signaling type %s",
 			       acct_gather_profile_type_t_name(i));
 
 			/* signal poller to start */
diff --git a/src/plugins/accounting_storage/filetxt/accounting_storage_filetxt.c b/src/plugins/accounting_storage/filetxt/accounting_storage_filetxt.c
index c8330427bb4e9c0f95ad62848e39785e9abc1bb7..b9bc41b5b2b76667e9cfc67b5cfeabf5c85f888a 100644
--- a/src/plugins/accounting_storage/filetxt/accounting_storage_filetxt.c
+++ b/src/plugins/accounting_storage/filetxt/accounting_storage_filetxt.c
@@ -719,7 +719,7 @@ extern int jobacct_storage_p_job_complete(void *db_conn,
 
 	exit_code = job_ptr->exit_code;
 	if (exit_code == 1) {
-		/* This wasn't signalled, it was set by Slurm so don't
+		/* This wasn't signaled, it was set by Slurm so don't
 		 * treat it like a signal.
 		 */
 		exit_code = 256;
diff --git a/src/plugins/accounting_storage/mysql/as_mysql_job.c b/src/plugins/accounting_storage/mysql/as_mysql_job.c
index 5e095e4bdffe1a92c57994eef7f358e62545b724..aaed30516a8e477528960a85b68489b15c124bbf 100644
--- a/src/plugins/accounting_storage/mysql/as_mysql_job.c
+++ b/src/plugins/accounting_storage/mysql/as_mysql_job.c
@@ -1027,7 +1027,7 @@ extern int as_mysql_job_complete(mysql_conn_t *mysql_conn,
 
 	exit_code = job_ptr->exit_code;
 	if (exit_code == 1) {
-		/* This wasn't signalled, it was set by Slurm so don't
+		/* This wasn't signaled, it was set by Slurm so don't
 		 * treat it like a signal.
 		 */
 		exit_code = 256;
diff --git a/src/plugins/select/alps/basil_interface.c b/src/plugins/select/alps/basil_interface.c
index 74c6bd0c34d55c01ce3f7ccdb11914113969b953..bb776d11a907e8437b823e3cc95759360b1a7de2 100644
--- a/src/plugins/select/alps/basil_interface.c
+++ b/src/plugins/select/alps/basil_interface.c
@@ -1060,7 +1060,7 @@ extern int do_basil_confirm(struct job_record *job_ptr)
 
 /**
  * do_basil_signal  -  pass job signal on to any APIDs
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  * IN signal  - signal(7) number
  * Only signal job if an ALPS reservation exists (non-0 reservation ID).
  */
@@ -1099,7 +1099,7 @@ void *_sig_basil(void *args)
 
 /**
  * queue_basil_signal  -  queue job signal on to any APIDs
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  * IN signal  - signal(7) number
  * IN delay   - how long to delay the signal, in seconds
  * Only signal job if an ALPS reservation exists (non-0 reservation ID).
diff --git a/src/plugins/select/alps/libalps/do_release.c b/src/plugins/select/alps/libalps/do_release.c
index 9a7c20e87124142714b5416026b58d7e70737a46..3e58c585428ccbe045722cf96f3666d00a83418b 100644
--- a/src/plugins/select/alps/libalps/do_release.c
+++ b/src/plugins/select/alps/libalps/do_release.c
@@ -76,7 +76,7 @@ int basil_signal_apids(int32_t rsvn_id, int signal, struct basil_inventory *inv)
 }
 
 /**
- * basil_safe_release  -  release reservation after signalling job steps
+ * basil_safe_release  -  release reservation after signaling job steps
  * @rsvn_id:	reservation to release
  * @inv:	recent Basil Inventory, or NULL to generate internally
  * Returns 0 if ok, a negative %basil_error otherwise.
diff --git a/src/plugins/select/other/other_select.c b/src/plugins/select/other/other_select.c
index f639b129ec64e4cfb057a05e159e2caa3751f1e8..a579260f86f64d738cccb46823f81a0344e1aaa8 100644
--- a/src/plugins/select/other/other_select.c
+++ b/src/plugins/select/other/other_select.c
@@ -347,7 +347,7 @@ extern int other_job_resized(struct job_record *job_ptr,
 
 /*
  * Pass job-step signal to other plugin.
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  * IN signal  - signal(7) number
  */
 extern int other_job_signal(struct job_record *job_ptr, int signal)
@@ -360,7 +360,7 @@ extern int other_job_signal(struct job_record *job_ptr, int signal)
 
 /*
  * Pass job memory allocation confirmation request to other plugin.
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  */
 extern int other_job_mem_confirm(struct job_record *job_ptr)
 {
diff --git a/src/plugins/select/other/other_select.h b/src/plugins/select/other/other_select.h
index e660a625e6d097108b67e08ba721a94f35ceaa40..f26fedc463a346c63e0512570d34a6edf274c31f 100644
--- a/src/plugins/select/other/other_select.h
+++ b/src/plugins/select/other/other_select.h
@@ -207,14 +207,14 @@ extern int other_job_resized(struct job_record *job_ptr,
 
 /*
  * Pass job-step signal to other plugin.
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  * IN signal  - signal(7) number
  */
 extern int other_job_signal(struct job_record *job_ptr, int signal);
 
 /*
  * Pass job memory allocation confirmation request to other plugin.
- * IN job_ptr - job to be signalled
+ * IN job_ptr - job to be signaled
  */
 extern int other_job_mem_confirm(struct job_record *job_ptr);
 
diff --git a/src/slurmctld/fed_mgr.c b/src/slurmctld/fed_mgr.c
index 70c6193ffcc66bb339b2bd540ae99681dce26ed0..ffa328606268a3e3d8f7a9658ecab2827ae3e166 100644
--- a/src/slurmctld/fed_mgr.c
+++ b/src/slurmctld/fed_mgr.c
@@ -1439,7 +1439,7 @@ static void _cleanup_removed_origin_jobs()
 			continue;
 
 		/* Free the resp_host so that the srun doesn't get
-		 * signalled about the job going away. The job could
+		 * signaled about the job going away. The job could
 		 * still run on another sibling. */
 		if (running_remotely ||
 		    (origin_id != sibling_id))
@@ -1529,7 +1529,7 @@ static void _cleanup_removed_cluster_jobs(slurmdb_cluster_rec_t *cluster)
 			      IS_JOB_RUNNING(job_ptr))) {
 
 				/* Free the resp_host so that the srun doesn't
-				 * get signalled about the job going away. The
+				 * get signaled about the job going away. The
 				 * job could still run on another sibling. */
 				xfree(job_ptr->resp_host);
 
diff --git a/src/slurmctld/power_save.c b/src/slurmctld/power_save.c
index 6d0e515ab4d7e0c5d7b82aa500bf9df4fb8e3332..7d00728e0be2cff465e1ac4195074e3c34fdbfea 100644
--- a/src/slurmctld/power_save.c
+++ b/src/slurmctld/power_save.c
@@ -494,7 +494,7 @@ static void _reap_procs(void)
 			} else
 				ping_nodes_now = true;
 		} else if (WIFSIGNALED(status)) {
-			error("power_save: program signalled: %s",
+			error("power_save: program signaled: %s",
 			      strsignal(WTERMSIG(status)));
 		}
 
diff --git a/src/slurmctld/srun_comm.c b/src/slurmctld/srun_comm.c
index dfd95c5fe2ad03df85b7bd2069590b6605e6dd02..f0a694217153ec62a44c5452eaba6227eea37b12 100644
--- a/src/slurmctld/srun_comm.c
+++ b/src/slurmctld/srun_comm.c
@@ -575,7 +575,7 @@ extern void srun_step_missing (struct step_record *step_ptr,
 }
 
 /*
- * srun_step_signal - notify srun that a job step should be signalled
+ * srun_step_signal - notify srun that a job step should be signaled
  * NOTE: Needed on BlueGene/Q to signal runjob process
  * IN step_ptr  - pointer to the slurmctld job step record
  * IN signal - signal number
diff --git a/src/slurmctld/srun_comm.h b/src/slurmctld/srun_comm.h
index 83ccb65c565f8d8507feb0343f9b11a1f44243bf..fb5b62bb21804e739f2d19090d42a72aa5fb2a6d 100644
--- a/src/slurmctld/srun_comm.h
+++ b/src/slurmctld/srun_comm.h
@@ -96,7 +96,7 @@ extern void srun_step_missing (struct step_record *step_ptr,
 			       char *node_list);
 
 /*
- * srun_step_signal - notify srun that a job step should be signalled
+ * srun_step_signal - notify srun that a job step should be signaled
  * NOTE: Needed on BlueGene/Q to signal runjob process
  * IN step_ptr  - pointer to the slurmctld job step record
  * IN signal - signal number
diff --git a/src/slurmd/slurmd/req.c b/src/slurmd/slurmd/req.c
index b4c52849012783e88d2c9d71e318c610eab4c770..d17197e7e3921e322fe2c77470cf5833cc5c8ea7 100644
--- a/src/slurmd/slurmd/req.c
+++ b/src/slurmd/slurmd/req.c
@@ -4715,7 +4715,7 @@ _rpc_signal_job(slurm_msg_t *msg)
 		}
 
 		if (stepd->stepid == SLURM_BATCH_SCRIPT) {
-			debug2("batch script itself not signalled");
+			debug2("batch script itself not signaled");
 			continue;
 		}
 
@@ -5392,7 +5392,7 @@ _rpc_terminate_job(slurm_msg_t *msg)
 	}
 
 	/*
-	 * Before signalling steps, if the job has any steps that are still
+	 * Before signaling steps, if the job has any steps that are still
 	 * in the process of fork/exec/check in with slurmd, wait on a condition
 	 * var for the start.  Otherwise a slow-starting step can miss the
 	 * job termination message and run indefinitely.
diff --git a/src/slurmd/slurmstepd/mgr.c b/src/slurmd/slurmstepd/mgr.c
index d5ac1758dcc9cd0539e0586d104d09607247a226..1fe0761a5abd41c655ab1e455d06a0a852ed98b8 100644
--- a/src/slurmd/slurmstepd/mgr.c
+++ b/src/slurmd/slurmstepd/mgr.c
@@ -307,7 +307,7 @@ static uint32_t _get_exit_code(stepd_step_rec_t *job)
 			debug("get_exit_code task %u called abort", i);
 			break;
 		}
-		/* If signalled we need to cycle thru all the
+		/* If signaled we need to cycle thru all the
 		 * tasks in case one of them called abort
 		 */
 		if (WIFSIGNALED(job->task[i]->estatus)) {
@@ -938,7 +938,7 @@ _bit_getrange(int start, int size, int *first, int *last)
 /*
  * Send as many step completion messages as necessary to represent
  * all completed nodes in the job step.  There may be nodes that have
- * not yet signalled their completion, so there will be gaps in the
+ * not yet signaled their completion, so there will be gaps in the
  * completed node bitmap, requiring that more than one message be sent.
  */
 static void
diff --git a/src/slurmd/slurmstepd/step_terminate_monitor.c b/src/slurmd/slurmstepd/step_terminate_monitor.c
index 464af54e18dfc976562e4ddc7e8b55aa1a8dbc7f..aea02144e58e730ff56540522056ee6cb5d8fa1a 100644
--- a/src/slurmd/slurmstepd/step_terminate_monitor.c
+++ b/src/slurmd/slurmstepd/step_terminate_monitor.c
@@ -99,7 +99,7 @@ void step_terminate_monitor_stop(void)
 	}
 
 	stop_flag = 1;
-	debug("step_terminate_monitor_stop signalling condition");
+	debug("step_terminate_monitor_stop signaling condition");
 	slurm_cond_signal(&cond);
 	slurm_mutex_unlock(&lock);
 
diff --git a/testsuite/expect/test37.16 b/testsuite/expect/test37.16
index 9908bb40897de54d50045a3f1aa31587631d2d61..2ffe6b120cb6fc227d08fbba23e163fea4981066 100755
--- a/testsuite/expect/test37.16
+++ b/testsuite/expect/test37.16
@@ -572,7 +572,7 @@ expect {
 	eof {}
 }
 if {$matches != 0} {
-	log_error "srun got signalled when it shouldn't have."
+	log_error "srun got signaled when it shouldn't have."
 	end_it 1
 }
 set timeout $old_timeout
diff --git a/testsuite/expect/test6.12 b/testsuite/expect/test6.12
index f69236a082d1f380588f0d9d32cb736cd57e2155..97c93f1775de2c2108be382cee84353de6818e0c 100755
--- a/testsuite/expect/test6.12
+++ b/testsuite/expect/test6.12
@@ -251,7 +251,7 @@ if {$exit_code != 0} {
 }
 
 #
-# Submit another job to be signalled with steps
+# Submit another job to be signaled with steps
 #
 set job_id      0
 file delete $file_out $file_err
diff --git a/src/api/step_launch.c b/src/api/step_launch.c
index 9a2f4e981c492b9f835215187e4f8ce3c0aa4617..b6516381c13212cd0044bafef1a66c5fbdffd055 100644
--- a/src/api/step_launch.c
+++ b/src/api/step_launch.c
@@ -679,7 +679,7 @@ void slurm_step_launch_wait_finish(slurm_step_ctx_t *ctx)
 				uint16_t kill_wait;
 				/* Only set the time once, because we only want
 				 * to wait STEP_ABORT_TIME, no matter how many
 				 * times the condition variable is signalled.
 				 */
 				kill_wait = slurm_get_kill_wait();
 				ts.tv_sec = time(NULL) + STEP_ABORT_TIME
@@ -897,7 +897,7 @@ void slurm_step_launch_fwd_signal(slurm_step_ctx_t *ctx, int signo)
 	list_iterator_destroy(itr);
 	FREE_NULL_LIST(ret_list);
 nothing_left:
-	debug2("All tasks have been signalled");
+	debug2("All tasks have been signaled");
 
 }
 
@@ -679,7 +679,7 @@ void slurm_step_launch_wait_finish(slurm_step_ctx_t *ctx)
 				/* Only set the time once, because we only want
 				 * to wait STEP_ABORT_TIME, no matter how many
-				 * times the condition variable is signalled.
+				 * times the condition variable is signaled.
 				 */
 				kill_wait = slurm_get_kill_wait();
diff --git a/src/slurmctld/job_mgr.c b/src/slurmctld/job_mgr.c
index 8432869b3705f515c414053dcc7adba3dae46e36..a19ce3c13be8eabc650080c251431da924305849 100644
--- a/src/slurmctld/job_mgr.c
+++ b/src/slurmctld/job_mgr.c
@@ -4775,7 +4775,7 @@ static int _job_signal(struct job_record *job_ptr, uint16_t signal,
 
 	/* If is origin job then cancel siblings -- if they exist.
 	 * origin job = because it knows where the siblings are
-	 * If the job is running locally then just do the normal signalling */
+	 * If the job is running locally then just do the normal signaling */
 	if (!(flags & KILL_NO_SIBS) && !IS_JOB_RUNNING(job_ptr) &&
 	    job_ptr->fed_details && fed_mgr_fed_rec) {
 		uint32_t origin_id = fed_mgr_get_cluster_id(job_ptr->job_id);
@@ -4805,7 +4805,7 @@ static int _job_signal(struct job_record *job_ptr, uint16_t signal,
 		}
 	}
 
-	/* let node select plugin do any state-dependent signalling actions */
+	/* let node select plugin do any state-dependent signaling actions */
 	select_g_job_signal(job_ptr, signal);
 	last_job_update = now;
 
@@ -5045,7 +5045,7 @@ extern int job_str_signal(char *job_id_str, uint16_t signal, uint16_t flags,
 	last_job_update = now;
 	job_id = (uint32_t) long_id;
 	if (end_ptr[0] == '\0') {	/* Single job (or full job array) */
-		int jobs_done = 0, jobs_signalled = 0;
+		int jobs_done = 0, jobs_signaled = 0;
 		struct job_record *job_ptr_done = NULL;
 		job_ptr = find_job_record(job_id);
 		if (job_ptr && job_ptr->pack_job_list) {
@@ -5078,7 +5078,7 @@ extern int job_str_signal(char *job_id_str, uint16_t signal, uint16_t flags,
 			rc = _job_signal(job_ptr, signal, flags, uid, preempt);
 			if (rc == ESLURM_ACCESS_DENIED)
 				return rc;
-			jobs_signalled++;
+			jobs_signaled++;
 			if (rc == ESLURM_ALREADY_DONE) {
 				jobs_done++;
 				rc = SLURM_SUCCESS;
@@ -5101,7 +5101,7 @@ extern int job_str_signal(char *job_id_str, uint16_t signal, uint16_t flags,
 			    (job_ptr != job_ptr_done)) {
 				rc2 = _job_signal(job_ptr, signal, flags, uid,
 						  preempt);
-				jobs_signalled++;
+				jobs_signaled++;
 				if (rc2 == ESLURM_ALREADY_DONE) {
 					jobs_done++;
 				} else {
@@ -5110,7 +5110,7 @@ extern int job_str_signal(char *job_id_str, uint16_t signal, uint16_t flags,
 			}
 			job_ptr = job_ptr->job_array_next_j;
 		}
-		if ((rc == SLURM_SUCCESS) && (jobs_done == jobs_signalled))
+		if ((rc == SLURM_SUCCESS) && (jobs_done == jobs_signaled))
 			return ESLURM_ALREADY_DONE;
 		return rc;
 
@@ -5136,7 +5136,7 @@ extern int job_str_signal(char *job_id_str, uint16_t signal, uint16_t flags,
 		goto endit;
 	}
 
-	/* Find some job record and validate the user signalling the job */
+	/* Find some job record and validate the user signaling the job */
 	job_ptr = find_job_record(job_id);
 	if (job_ptr == NULL) {
 		job_ptr = job_array_hash_j[JOB_HASH_INX(job_id)];
@@ -5284,7 +5284,7 @@ _signal_batch_job(struct job_record *job_ptr, uint16_t signal, uint16_t flags)
 	kill_tasks_msg->job_id      = job_ptr->job_id;
 	kill_tasks_msg->job_step_id = NO_VAL;
 
 	/* Encode the flags for slurm stepd to know what steps get signalled */
 	if (flags == KILL_FULL_JOB)
 		z = KILL_FULL_JOB << 24;
 	else if (flags == KILL_JOB_BATCH)
@@ -8065,7 +8065,7 @@ void job_time_limit(void)
 						  job_ptr->warn_flags, 0,
 						  false);
 
 				/* mark job as signalled */
 				job_ptr->warn_flags |= WARN_SENT;
 			}
 			if (job_ptr->end_time <= now) {
@@ -8115,7 +8115,7 @@ void job_time_limit(void)
 						  job_ptr->warn_flags, 0,
 						  false);
 
 				/* mark job as signalled */
 				job_ptr->warn_flags |= WARN_SENT;
 			}
 			if ((job_ptr->mail_type & MAIL_JOB_TIME100) &&
@@ -5284,7 +5284,7 @@ _signal_batch_job(struct job_record *job_ptr, uint16_t signal, uint16_t flags)
 	kill_tasks_msg->job_step_id = NO_VAL;
 
-	/* Encode the flags for slurm stepd to know what steps get signalled */
+	/* Encode the flags for slurm stepd to know what steps get signaled */
 	if (flags == KILL_FULL_JOB)
 		z = KILL_FULL_JOB << 24;
@@ -8065,7 +8065,7 @@ void job_time_limit(void)
 						  false);
 
-				/* mark job as signalled */
+				/* mark job as signaled */
 				job_ptr->warn_flags |= WARN_SENT;
 			}
@@ -8115,7 +8115,7 @@ void job_time_limit(void)
 						  false);
 
-				/* mark job as signalled */
+				/* mark job as signaled */
 				job_ptr->warn_flags |= WARN_SENT;
 			}